import json

class MarketData:
    def zero_rate_curve(self, currency, asof_date):
        return []

class SimpleResponse:
    def __init__(self):
        self.value = None
        self.errors = []
        self.warnings = []

    def error(self, message):
        self.errors.append(message)

    def warning(self, message):
        self.warnings.append(message)
    
    def __str__(self):
        # Using json.dumps to format the output
        return json.dumps(self.__dict__, indent=4)

class InstrumentPricer:
    def __init__(self, model):
        self.model = model

    async def async_price(self, quotation_request, quote):
        quote.error("Not implemented")
        return quote

class MissingDataException(Exception):
    pass

class CalculationError(Exception):
    pass



from setuptools import setup

setup(
    name='tdone',
    version='0.1.1',    
    description='TD ONE: A Python Package for Banking and Pricing',
    url='https://github.com/tpdrg/tdone',
    author='Behrang Dadsetan',
    author_email='behrang.dadsetan@tpdrg.com',
    license='BSD 2-clause',
    packages=['tdone'],
    install_requires=['pika>=1.3.2',                  
                      ],

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',  
        'Operating System :: POSIX :: Linux',        
        'Operating System :: Microsoft :: Windows',        
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11'
    ],
)